==> mfc-vms-meta-model-0.1.0-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/media/base/AbstractMedia.java <==
package com.valor.mfc.vms.meta.model.database.ddo.media.base;

import com.google.common.base.Objects;

import com.valor.mfc.vms.api.model.constant.EVideoType;

import org.hibernate.annotations.NaturalId;

import javax.persistence.Column;
import javax.persistence.MappedSuperclass;

/**
 * Created by Frank.Huang on 2016/4/28.
 */
@MappedSuperclass
public abstract class AbstractMedia extends AbstractId {

    @Column(name="type")
    protected EVideoType type;

    @Column(name = "publication_year",columnDefinition="int default -1")
    protected int publicationYear = -1;

    @Column(name = "release_date",length = 10)    //first release date
    protected String releaseDate="";

    @Column(name = "release_country",length = 1024) //first release country
    protected String releaseCountry="";

    @Column(name = "release_country_code",length = 1024) //first release country
    protected String releaseCountryCode="";

    @Column(name = "runtime",columnDefinition="int default 0")
    protected long runtime = 0;

    @Column(name = "popularity", columnDefinition="double(20,4) default 0.0")
    protected double popularity = 0.0;

    @Column(name = "adult", columnDefinition="int default 0")
    protected int adult = 0;

    @Column(name = "original_title",columnDefinition="varchar(512) default ''")
    protected String originalTitle="";

    @Column(name = "original_language", columnDefinition="varchar(512) default ''")
    protected String originalLanguage="";

    @Column(name = "original_Country", columnDefinition="varchar(512) default ''")
    protected String originalCountry ="";

    @Column(name = "display_id",columnDefinition="varchar(16) default ''")
    protected String displayId="";

    @NaturalId
    @Column(name = "imdb_id",columnDefinition="varchar(16) default ''")
    protected String imdbId="";

    @Column(name = "tmdb_id", columnDefinition="int default -1")
    protected long tmdbId=0;

    @Column(name = "rating",columnDefinition="double(9,1) default 0.0")
    protected double rating=0.0;

    @Column(name = "vote_count",columnDefinition="int default 0")
    protected int voteCount = 0;

    @Column(name = "status",columnDefinition="int default 0")
    protected int status = 0;

    @Column(name = "complete",columnDefinition="int default 0")
    protected int complete = 0;

    @Column(name = "manual",columnDefinition="int default 0")
    protected int manual = 0;

    @Column(name = "WR",columnDefinition="double(9,1) default 0.0")
    protected double WR=0.0;

    @Column(name = "meta_id",columnDefinition="varchar(16) default ''")
    protected String metaId="";

    @Column(name = "release_date_int",columnDefinition="int  default 0")
    protected int releaseDateInt = 0;

    public int getManual() {
        return manual;
    }

    public void setManual(int manual) {
        this.manual = manual;
    }

    public String getDisplayId() {
        return displayId;
    }

    public void setDisplayId(String displayId) {
        this.displayId = displayId;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    public int getComplete() {
        return complete;
    }

    public void setComplete(int complete) {
        this.complete = complete;
    }

    public EVideoType getType() {
        return type;
    }

    public void setType(EVideoType type) {
        this.type = type;
    }

    public int getPublicationYear() {
        return publicationYear;
    }

    public void setPublicationYear(int publicationYear) {
        this.publicationYear = publicationYear;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public long getRuntime() {
        return runtime;
    }

    public void setRuntime(long runtime) {
        this.runtime = runtime;
    }

    public double getPopularity() {
        return popularity;
    }

    public void setPopularity(double popularity) {
        this.popularity = popularity;
    }

    public int getAdult() {
        return adult;
    }

    public void setAdult(int adult) {
        this.adult = adult;
    }

    public String getOriginalTitle() {
        return originalTitle;
    }

    public void setOriginalTitle(String originalTitle) {
        this.originalTitle = originalTitle;
    }

    public String getOriginalLanguage() {
        return originalLanguage;
    }

    public void setOriginalLanguage(String originalLanguage) {
        this.originalLanguage = originalLanguage;
    }

    public String getOriginalCountry() {
        return originalCountry;
    }

    public void setOriginalCountry(String originalCountry) {
        this.originalCountry = originalCountry;
    }

    public String getImdbId() {
        return imdbId;
    }

    public void setImdbId(String imdbId) {
        this.imdbId = imdbId;
    }

    public long getTmdbId() {
        return tmdbId;
    }

    public void setTmdbId(long tmdbId) {
        this.tmdbId = tmdbId;
    }

    public double getRating() {
        return rating;
    }

    public void setRating(double rating) {
        this.rating = rating;
    }

    public int getVoteCount() {
        return voteCount;
    }

    public void setVoteCount(int voteCount) {
        this.voteCount = voteCount;
    }

    public double getWR() {
        return WR;
    }

    public void setWR(double WR) {
        this.WR = WR;
    }

    public String getReleaseCountry() {
        return releaseCountry;
    }

    public void setReleaseCountry(String releaseCountry) {
        this.releaseCountry = releaseCountry;
    }

    public String getReleaseCountryCode() {
        return releaseCountryCode;
    }

    public void setReleaseCountryCode(String releaseCountryCode) {
        this.releaseCountryCode = releaseCountryCode;
    }

    public String getMetaId() {
        return metaId;
    }

    public void setMetaId(String metaId) {
        this.metaId = metaId;
    }

    public int getReleaseDateInt() {
        return releaseDateInt;
    }

    public void setReleaseDateInt(int releaseDateInt) {
        this.releaseDateInt = releaseDateInt;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        AbstractMedia that = (AbstractMedia) o;

        return Objects.equal(this.id, that.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }
}

==> mfc-vms-meta-model-0.1.1-sources.jar: com/valor/mfc/vms/meta/model/database/ddo/media/base/AbstractMedia.java <==
package com.valor.mfc.vms.meta.model.database.ddo.media.base;

import com.google.common.base.Objects;

import com.valor.mfc.vms.api.model.constant.EVideoType;

import org.hibernate.annotations.NaturalId;

import javax.persistence.Column;
import javax.persistence.MappedSuperclass;

/**
 * Created by Frank.Huang on 2016/4/28.
 */
@MappedSuperclass
public abstract class AbstractMedia extends AbstractId {

    @Column(name="type")
    protected EVideoType type;

    @Column(name = "publication_year",columnDefinition="int default -1")
    protected int publicationYear = -1;

    @Column(name = "release_date",length = 10)    //first release date
    protected String releaseDate="";

    @Column(name = "release_country",length = 1024) //first release country
    protected String releaseCountry="";

    @Column(name = "release_country_code",length = 1024) //first release country
    protected String releaseCountryCode="";

    @Column(name = "runtime",columnDefinition="int default 0")
    protected long runtime = 0;

    @Column(name = "popularity", columnDefinition="double(20,4) default 0.0")
    protected double popularity = 0.0;

    @Column(name = "adult", columnDefinition="int default 0")
    protected int adult = 0;

    @Column(name = "original_title",columnDefinition="varchar(512) default ''")
    protected String originalTitle="";

    @Column(name = "original_language", columnDefinition="varchar(1023) default ''")
    protected String originalLanguage="";

    @Column(name = "original_Country", columnDefinition="varchar(1023) default ''")
    protected String originalCountry ="";

    @Column(name = "display_id",columnDefinition="varchar(16) default ''")
    protected String displayId="";

    @NaturalId(mutable = true)
    @Column(name = "imdb_id",nullable = false, updatable = true, unique = true,columnDefinition="varchar(31) default ''")
    protected String imdbId="";

    @Column(name = "tmdb_id", columnDefinition="int default -1")
    protected long tmdbId=0;

    @Column(name = "rating",columnDefinition="double(9,1) default 0.0")
    protected double rating=0.0;

    @Column(name = "vote_count",columnDefinition="int default 0")
    protected int voteCount = 0;

    @Column(name = "status",columnDefinition="int default 0")
    protected int status = 0;

    @Column(name = "complete",columnDefinition="int default 0")
    protected int complete = 0;

    @Column(name = "manual",columnDefinition="int default 0")
    protected int manual = 0;

    @Column(name = "WR",columnDefinition="double(9,1) default 0.0")
    protected double WR=0.0;

    @Column(name = "meta_id",columnDefinition="varchar(16) default ''")
    protected String metaId="";

    @Column(name = "release_date_int",columnDefinition="int  default 0")
    protected int releaseDateInt = 0;

    @Column(name = "pp_id",columnDefinition="varchar(31) default ''")
    protected String ppId="";

    public int getManual() {
        return manual;
    }

    public void setManual(int manual) {
        this.manual = manual;
    }

    public String getDisplayId() {
        return displayId;
    }

    public void setDisplayId(String displayId) {
        this.displayId = displayId;
    }

    public int getStatus() {
        return status;
    }

    public void setStatus(int status) {
        this.status = status;
    }

    public int getComplete() {
        return complete;
    }

    public void setComplete(int complete) {
        this.complete = complete;
    }

    public EVideoType getType() {
        return type;
    }

    public void setType(EVideoType type) {
        this.type = type;
    }

    public int getPublicationYear() {
        return publicationYear;
    }

    public void setPublicationYear(int publicationYear) {
        this.publicationYear = publicationYear;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public long getRuntime() {
        return runtime;
    }

    public void setRuntime(long runtime) {
        this.runtime = runtime;
    }

    public double getPopularity() {
        return popularity;
    }

    public void setPopularity(double popularity) {
        this.popularity = popularity;
    }

    public int getAdult() {
        return adult;
    }

    public void setAdult(int adult) {
        this.adult = adult;
    }

    public String getOriginalTitle() {
        return originalTitle;
    }

    public void setOriginalTitle(String originalTitle) {
        this.originalTitle = originalTitle;
    }

    public String getOriginalLanguage() {
        return originalLanguage;
    }

    public void setOriginalLanguage(String originalLanguage) {
        this.originalLanguage = originalLanguage;
    }

    public String getOriginalCountry() {
        return originalCountry;
    }

    public void setOriginalCountry(String originalCountry) {
        this.originalCountry = originalCountry;
    }

    public String getImdbId() {
        return imdbId;
    }

    public void setImdbId(String imdbId) {
        this.imdbId = imdbId;
    }

    public long getTmdbId() {
        return tmdbId;
    }

    public void setTmdbId(long tmdbId) {
        this.tmdbId = tmdbId;
    }

    public double getRating() {
        return rating;
    }

    public void setRating(double rating) {
        this.rating = rating;
    }

    public int getVoteCount() {
        return voteCount;
    }

    public void setVoteCount(int voteCount) {
        this.voteCount = voteCount;
    }

    public double getWR() {
        return WR;
    }

    public void setWR(double WR) {
        this.WR = WR;
    }

    public String getReleaseCountry() {
        return releaseCountry;
    }

    public void setReleaseCountry(String releaseCountry) {
        this.releaseCountry = releaseCountry;
    }

    public String getReleaseCountryCode() {
        return releaseCountryCode;
    }

    public void setReleaseCountryCode(String releaseCountryCode) {
        this.releaseCountryCode = releaseCountryCode;
    }

    public String getMetaId() {
        return metaId;
    }

    public void setMetaId(String metaId) {
        this.metaId = metaId;
    }

    public int getReleaseDateInt() {
        return releaseDateInt;
    }

    public void setReleaseDateInt(int releaseDateInt) {
        this.releaseDateInt = releaseDateInt;
    }

    public String getPpId() {
        return ppId;
    }

    public void setPpId(String ppId) {
        this.ppId = ppId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        AbstractMedia that = (AbstractMedia) o;

        return Objects.equal(this.id, that.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }
}
